@@ -25,7 +25,7 @@ import xml.dom.minidom
 # SET VERSION
 # -----------
 
-version = '5.2.0'
+version = '5.3.0'
 nightbuild = ''
 
 
@@ -91,7 +91,6 @@ main={
     'macListCtrlGeneric': 1,
     'peaklistColumns': ['mz', 'int', 'rel', 'sn', 'z', 'fwhm', 'resol'],
     'cursorInfo': ['mz', 'dist', 'ppm', 'z'],
-    'donate': '',
     'updatesEnabled': 1,
     'updatesChecked': '',
     'updatesCurrent': version,
@@ -240,6 +239,7 @@ processing={
         'forceGroupWindow': 0,
     },
     'batch':{
+        'swap': 0,
         'math': 0,
         'crop': 0,
         'baseline': 0,
@@ -345,6 +345,17 @@ massToFormula={
     'LipidMAPSScript': 'http://www.lipidmaps.org/data/structure/LMSDSearch.php',
 }
 
+massDefectPlot={
+    'xAxis': 'm/z',
+    'yAxis': 'Mass Defect',
+    'groupFormula': '',
+    'nominalMass': 'floor',
+    'relIntCutoff': 0.0,
+    'ignoreCharge': 1,
+    'removeIsotopes': 0,
+    'showNotations': 0,
+}
+
 compoundsSearch={
     'massType': 0,
     'maxCharge': 1,
@@ -749,6 +760,11 @@ def loadConfig(path=os.path.join(confdir, 'config.xml')):
         if type(massToFormula['rules']) != list:
             massToFormula['rules'] = massToFormula['rules'].split(';')
     
+    # mass defect plot
+    massDefectPlotTags = document.getElementsByTagName('massDefectPlot')
+    if massDefectPlotTags:
+        _getParams(massDefectPlotTags[0], massDefectPlot)
+    
     # compounds search
     compoundsSearchTags = document.getElementsByTagName('compoundsSearch')
     if compoundsSearchTags:
@@ -877,7 +893,6 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="printQuality" value="%d" type="int" />\n' % (main['printQuality'])
     buff += '    <param name="useServer" value="%d" type="int" />\n' % (bool(main['useServer']))
     buff += '    <param name="serverPort" value="%d" type="int" />\n' % (main['serverPort'])
-    buff += '    <param name="donate" value="%s" type="str" />\n' % (main['donate'])
     buff += '    <param name="updatesEnabled" value="%d" type="int" />\n' % (bool(main['updatesEnabled']))
     buff += '    <param name="updatesChecked" value="%s" type="str" />\n' % (main['updatesChecked'])
     buff += '    <param name="updatesCurrent" value="%s" type="str" />\n' % (main['updatesCurrent'])
@@ -1098,6 +1113,18 @@ def saveConfig(path=os.path.join(confdir, 'config.xml')):
     buff += '    <param name="LipidMAPSScript" value="%s" type="unicode" />\n' % (_escape(massToFormula['LipidMAPSScript']))
     buff += '  </massToFormula>\n\n'
     
+    # mass defect plot
+    buff += '  <massDefectPlot>\n'
+    buff += '    <param name="xAxis" value="%s" type="str" />\n' % (massDefectPlot['xAxis'])
+    buff += '    <param name="yAxis" value="%s" type="str" />\n' % (massDefectPlot['yAxis'])
+    buff += '    <param name="groupFormula" value="%s" type="str" />\n' % (massDefectPlot['groupFormula'])
+    buff += '    <param name="nominalMass" value="%s" type="str" />\n' % (massDefectPlot['nominalMass'])
+    buff += '    <param name="relIntCutoff" value="%f" type="float" />\n' % (massDefectPlot['relIntCutoff'])
+    buff += '    <param name="ignoreCharge" value="%d" type="int" />\n' % (bool(massDefectPlot['ignoreCharge']))
+    buff += '    <param name="removeIsotopes" value="%d" type="int" />\n' % (bool(massDefectPlot['removeIsotopes']))
+    buff += '    <param name="showNotations" value="%d" type="int" />\n' % (bool(massDefectPlot['showNotations']))
+    buff += '  </massDefectPlot>\n\n'
+    
     # compounds search
     buff += '  <compoundsSearch>\n'
     buff += '    <param name="massType" value="%d" type="int" />\n' % (compoundsSearch['massType'])
