@@ -48,6 +48,11 @@ ID_documentOffset = wx.NewId()
 ID_documentClearOffset = wx.NewId()
 ID_documentClearOffsets = wx.NewId()
 ID_documentColour = wx.NewId()
+ID_documentStyle = wx.NewId()
+ID_documentStyleSolid = wx.NewId()
+ID_documentStyleDot = wx.NewId()
+ID_documentStyleDash = wx.NewId()
+ID_documentStyleDotDash = wx.NewId()
 ID_documentAnnotationEdit = wx.NewId()
 ID_documentAnnotationDelete = wx.NewId()
 ID_documentAnnotationSendToMassCalculator = wx.NewId()
@@ -193,6 +198,7 @@ ID_toolsOffset = wx.NewId()
 ID_toolsPeriodicTable = wx.NewId()
 ID_toolsMassCalculator = wx.NewId()
 ID_toolsMassToFormula = wx.NewId()
+ID_toolsMassDefectPlot = wx.NewId()
 ID_toolsMassFilter = wx.NewId()
 ID_toolsCompoundsSearch = wx.NewId()
 ID_toolsPeakDifferences = wx.NewId()
@@ -215,6 +221,7 @@ HK_toolsDeleteLabel = '\tShift+Ctrl+X'
 HK_toolsPeriodicTable = '\tShift+Ctrl+T'
 HK_toolsMassCalculator = '\tShift+Ctrl+M'
 HK_toolsMassToFormula = '\tShift+Ctrl+B'
+HK_toolsMassDefectPlot = '\tShift+Ctrl+O'
 HK_toolsMassFilter = '\tShift+Ctrl+F'
 HK_toolsCompoundsSearch = '\tShift+Ctrl+U'
 HK_toolsPeakDifferences = '\tShift+Ctrl+D'
