@@ -16,6 +16,7 @@
 # -------------------------------------------------------------------------
 
 # load libs
+import threading
 import wx
 import wx.grid
 
@@ -36,10 +37,15 @@ class panelComparePeaklists(wx.MiniFrame):
         wx.MiniFrame.__init__(self, parent, -1, 'Compare Peak Lists', size=(500, 400), style=wx.DEFAULT_FRAME_STYLE)
         
         self.parent = parent
+        
+        self.processing = None
+        
         self.currentDocuments = []
-        self.currentPeaklists = []
+        self.currentPeaklist = []
         self.currentMatches = []
         
+        self._maxSize = 0
+        
         # make gui items
         self.makeGUI()
         wx.EVT_CLOSE(self, self.onClose)
@@ -54,11 +60,16 @@ class panelComparePeaklists(wx.MiniFrame):
         
         # make panel
         mainPanel = self.makeMainPanel()
+        gauge = self.makeGaugePanel()
         
         # pack element
         self.mainSizer = wx.BoxSizer(wx.VERTICAL)
         self.mainSizer.Add(toolbar, 0, wx.EXPAND, 0)
         self.mainSizer.Add(mainPanel, 1, wx.EXPAND, 0)
+        self.mainSizer.Add(gauge, 0, wx.EXPAND, 0)
+        
+        # hide gauge
+        self.mainSizer.Hide(2)
         
         # fit layout
         self.mainSizer.Fit(self)
@@ -79,7 +90,7 @@ class panelComparePeaklists(wx.MiniFrame):
         
         choices = ['Peak Lists', 'Notations (measured)', 'Notations (theoretical)']
         self.compare_choice = wx.Choice(panel, -1, choices=choices, size=(180, mwx.SMALL_CHOICE_HEIGHT))
-        self.compare_choice.Bind(wx.EVT_CHOICE, self.onCompareChanged)
+        self.compare_choice.Bind(wx.EVT_CHOICE, self.onUpdatePeaklist)
         self.compare_choice.Select(0)
         if config.comparePeaklists['compare'] == 'measured':
             self.compare_choice.Select(1)
@@ -104,9 +115,23 @@ class panelComparePeaklists(wx.MiniFrame):
         self.ignoreCharge_check.SetFont(wx.SMALL_FONT)
         self.ignoreCharge_check.SetValue(config.comparePeaklists['ignoreCharge'])
         
+        self.ratioCheck_check = wx.CheckBox(panel, -1, "Int. ratio:")
+        self.ratioCheck_check.SetFont(wx.SMALL_FONT)
+        self.ratioCheck_check.SetValue(config.comparePeaklists['ratioCheck'])
+        self.ratioCheck_check.Bind(wx.EVT_CHECKBOX, self.onRatioCheckChanged)
+        
+        self.ratioDirection_choice = wx.Choice(panel, -1, choices=['Above', 'Below'], size=(80, mwx.SMALL_CHOICE_HEIGHT))
+        self.ratioDirection_choice.Select(0)
+        if config.comparePeaklists['ratioDirection'] == -1:
+            self.ratioDirection_choice.Select(1)
+        
+        self.ratioThreshold_value = wx.TextCtrl(panel, -1, str(config.comparePeaklists['ratioThreshold']), size=(50, -1), validator=mwx.validator('floatPos'))
+        
         self.compare_butt = wx.Button(panel, -1, "Compare", size=(-1, mwx.SMALL_BUTTON_HEIGHT))
         self.compare_butt.Bind(wx.EVT_BUTTON, self.onCompare)
         
+        self.onRatioCheckChanged()
+        
         # pack elements
         sizer = wx.BoxSizer(wx.HORIZONTAL)
         sizer.AddSpacer(mwx.CONTROLBAR_LSPACE)
@@ -120,6 +145,10 @@ class panelComparePeaklists(wx.MiniFrame):
         sizer.Add(self.unitsPpm_radio, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddSpacer(20)
         sizer.Add(self.ignoreCharge_check, 0, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(20)
+        sizer.Add(self.ratioCheck_check, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 5)
+        sizer.Add(self.ratioDirection_choice, 0, wx.ALIGN_CENTER_VERTICAL|wx.RIGHT, 10)
+        sizer.Add(self.ratioThreshold_value, 0, wx.ALIGN_CENTER_VERTICAL)
         sizer.AddStretchSpacer()
         sizer.AddSpacer(20)
         sizer.Add(self.compare_butt, 0, wx.ALIGN_CENTER_VERTICAL)
@@ -141,12 +170,15 @@ class panelComparePeaklists(wx.MiniFrame):
         
         # make grids
         self.makeDocumentsGrid(panel)
+        self.makePeaklistGrid(panel)
         self.makeMatchesGrid(panel)
         
         # pack main
         mainSizer = wx.BoxSizer(wx.HORIZONTAL)
         mainSizer.Add(self.documentsGrid, 1, wx.EXPAND)
         mainSizer.AddSpacer(mwx.SASH_SIZE)
+        mainSizer.Add(self.peaklistGrid, 0, wx.EXPAND)
+        mainSizer.AddSpacer(mwx.SASH_SIZE)
         mainSizer.Add(self.matchesGrid, 0, wx.EXPAND)
         
         # fit layout
@@ -160,7 +192,7 @@ class panelComparePeaklists(wx.MiniFrame):
         """Make documents grid."""
         
         # make table
-        self.documentsGrid = wx.grid.Grid(panel, -1, size=(600, 400), style=mwx.GRID_STYLE)
+        self.documentsGrid = wx.grid.Grid(panel, -1, size=(550, 500), style=mwx.GRID_STYLE)
         self.documentsGrid.CreateGrid(0, 0)
         self.documentsGrid.DisableDragColSize()
         self.documentsGrid.DisableDragRowSize()
@@ -178,6 +210,28 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
+    def makePeaklistGrid(self, panel):
+        """Make total peaklist grid."""
+        
+        # make table
+        self.peaklistGrid = wx.grid.Grid(panel, -1, size=(225, 400), style=mwx.GRID_STYLE)
+        self.peaklistGrid.CreateGrid(0, 0)
+        self.peaklistGrid.DisableDragColSize()
+        self.peaklistGrid.DisableDragRowSize()
+        self.peaklistGrid.SetColLabelSize(19)
+        self.peaklistGrid.SetRowLabelSize(0)
+        self.peaklistGrid.SetDefaultRowSize(19)
+        self.peaklistGrid.AutoSizeColumns(True)
+        self.peaklistGrid.SetLabelFont(wx.SMALL_FONT)
+        self.peaklistGrid.SetDefaultCellFont(wx.SMALL_FONT)
+        self.peaklistGrid.SetDefaultCellAlignment(wx.ALIGN_RIGHT, wx.ALIGN_TOP)
+        self.peaklistGrid.SetDefaultCellBackgroundColour(wx.WHITE)
+        
+        self.peaklistGrid.Bind(wx.grid.EVT_GRID_SELECT_CELL, self.onPeaklistCellSelected)
+        self.peaklistGrid.Bind(wx.EVT_KEY_DOWN, self.onPeaklistKey)
+    # ----
+    
+    
     def makeMatchesGrid(self, panel):
         """Make matches grid."""
         
@@ -199,58 +253,96 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
+    def makeGaugePanel(self):
+        """Make processing gauge."""
+        
+        panel = wx.Panel(self, -1)
+        
+        # make elements
+        self.gauge = mwx.gauge(panel, -1)
+        
+        stop_butt = wx.BitmapButton(panel, -1, images.lib['stopper'], style=wx.BORDER_NONE)
+        stop_butt.Bind(wx.EVT_BUTTON, self.onStop)
+        
+        # pack elements
+        sizer = wx.BoxSizer(wx.HORIZONTAL)
+        sizer.Add(self.gauge, 1, wx.ALIGN_CENTER_VERTICAL)
+        sizer.AddSpacer(10)
+        sizer.Add(stop_butt, 0, wx.ALIGN_CENTER_VERTICAL)
+        
+        # fit layout
+        mainSizer = wx.BoxSizer(wx.VERTICAL)
+        if wx.Platform == '__WXMAC__':
+            mainSizer.Add(wx.StaticLine(panel), 0, wx.EXPAND|wx.TOP, -1)
+        mainSizer.Add(sizer, 1, wx.EXPAND|wx.ALL, mwx.GAUGE_SPACE)
+        panel.SetSizer(mainSizer)
+        mainSizer.Fit(panel)
+        
+        return panel
+    # ----
+    
+    
     def onClose(self, evt):
-        """Destroy this frame."""
+        """Hide this frame."""
+        
+        # check processing
+        if self.processing != None:
+            wx.Bell()
+            return
+        
+        # close self
         self.Destroy()
     # ----
     
     
-    def onCompare(self, evt):
-        """Compare data."""
+    def onProcessing(self, status=True):
+        """Show processing gauge."""
         
-        # check documents
-        if not self.currentDocuments:
-            wx.Bell()
-            return
+        self.gauge.SetValue(0)
         
-        # get params
-        if not self.getParams():
-            wx.Bell()
-            return
+        if status:
+            self.MakeModal(True)
+            self.mainSizer.Show(2)
+        else:
+            self.MakeModal(False)
+            self.mainSizer.Hide(2)
+            self.processing = None
+            mspy.start()
         
-        # compare
-        self.compareAll()
-        
-        # update gui
-        self.updateDocumentsGrid()
-        self.updateMatchesGrid()
+        # fit layout
+        self.documentsGrid.SetMinSize(self.documentsGrid.GetSize())
+        self.Layout()
+        self.mainSizer.Fit(self)
+        try: wx.Yield()
+        except: pass
+        self.documentsGrid.SetMinSize((-1,-1))
     # ----
     
     
-    def onCompareChanged(self, evt):
-        """Get relevant peaks lists."""
+    def onStop(self, evt):
+        """Cancel current processing."""
         
-        # get data type
-        value = self.compare_choice.GetStringSelection()
-        if value == 'Notations (measured)':
-            config.comparePeaklists['compare'] = 'measured'
-        elif value == 'Notations (theoretical)':
-            config.comparePeaklists['compare'] = 'theoretical'
+        if self.processing and self.processing.isAlive():
+            mspy.stop()
         else:
-            config.comparePeaklists['compare'] = 'peaklists'
+            wx.Bell()
+    # ----
+    
+    
+    def onRatioCheckChanged(self, evt=None):
+        """Disable ratio chacking options."""
         
-        # get peaklists
-        self.getPeaklists()
-        
-        # update gui
-        self.updateDocumentsGrid()
-        self.updateMatchesGrid()
+        enabled = self.ratioCheck_check.IsChecked()
+        self.ratioDirection_choice.Enable(enabled)
+        self.ratioThreshold_value.Enable(enabled)
     # ----
     
     
     def onDocumentsCellSelected(self, evt):
         """Show more info for selected cell."""
         
+        evt.Skip()
+        
         # check documents
         if not self.currentDocuments:
             return
@@ -258,24 +350,53 @@ class panelComparePeaklists(wx.MiniFrame):
         # get slection
         col = evt.GetCol()
         row = evt.GetRow()
+        
+        # get peak index
         docIndex = int(col) / int((len(self.currentDocuments)+1))
+        pkIndex = None
+        count = -1
+        for i, item in enumerate(self.currentPeaklist):
+            if item[1] == docIndex:
+                count += 1
+            if count == row:
+                pkIndex = i
+                break
         
-        # check position
-        if col % (len(self.currentDocuments)+1) != 0:
+        # check peak index
+        if pkIndex == None:
+            self.currentMatches = []
+            self.updateMatchesGrid()
             return
-        elif row >= len(self.currentPeaklists[docIndex]):
-            return
-        else:
-            evt.Skip()
-        
-        # highlight selected cell
-        self.documentsGrid.SelectBlock(row, col, row, col)
         
         # highlight mass in plot
-        self.parent.updateMassPoints([self.currentPeaklists[docIndex][row][0]])
+        self.parent.updateMassPoints([self.currentPeaklist[pkIndex][0]])
         
         # compare selected mass
-        self.compareSelected(docIndex, row)
+        self.compareSelected(pkIndex)
+        self.updateMatchesGrid()
+    # ----
+    
+    
+    def onPeaklistCellSelected(self, evt):
+        """Show more info for selected cell."""
+        
+        evt.Skip()
+        
+        # check documents
+        if not self.currentDocuments:
+            return
+        
+        # get slection
+        row = evt.GetRow()
+        
+        # get peak index
+        pkIndex = row
+        
+        # highlight mass in plot
+        self.parent.updateMassPoints([self.currentPeaklist[pkIndex][0]])
+        
+        # compare selected mass
+        self.compareSelected(pkIndex)
         self.updateMatchesGrid()
     # ----
     
@@ -296,6 +417,22 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
+    def onPeaklistKey(self, evt):
+        """Key pressed."""
+        
+        # get key
+        key = evt.GetKeyCode()
+        
+        # copy
+        if key == 67 and evt.CmdDown():
+            self.copyPeaklist()
+        
+        # other keys
+        else:
+            evt.Skip()
+    # ----
+    
+    
     def onMatchesKey(self, evt):
         """Key pressed."""
         
@@ -312,11 +449,95 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
+    def onCompare(self, evt):
+        """Compare data."""
+        
+        # check processing
+        if self.processing:
+            return
+        
+        # check documents
+        if not self.currentDocuments:
+            wx.Bell()
+            return
+        
+        # get params
+        if not self.getParams():
+            wx.Bell()
+            return
+        
+        # show processing gauge
+        self.onProcessing(True)
+        self.compare_butt.Enable(False)
+        
+        # do processing
+        self.processing = threading.Thread(target=self.runCompare)
+        self.processing.start()
+        
+        # pulse gauge while working
+        while self.processing and self.processing.isAlive():
+            self.gauge.pulse()
+        
+        # update gui
+        self.updateDocumentsGrid(recreate=False)
+        self.updatePeaklistGrid(recreate=False)
+        self.updateMatchesGrid()
+        
+        # hide processing gauge
+        self.onProcessing(False)
+        self.compare_butt.Enable(True)
+    # ----
+    
+    
+    def onUpdatePeaklist(self, evt=None):
+        """Get relevant peaks lists."""
+        
+        # check processing
+        if self.processing:
+            return
+        
+        # get peak list type
+        value = self.compare_choice.GetStringSelection()
+        if value == 'Notations (measured)':
+            config.comparePeaklists['compare'] = 'measured'
+        elif value == 'Notations (theoretical)':
+            config.comparePeaklists['compare'] = 'theoretical'
+        else:
+            config.comparePeaklists['compare'] = 'peaklists'
+        
+        # check documents
+        if not self.currentDocuments:
+            wx.Bell()
+            return
+        
+        # show processing gauge
+        self.onProcessing(True)
+        self.compare_butt.Enable(False)
+        
+        # do processing
+        self.processing = threading.Thread(target=self.runGetPeaklists)
+        self.processing.start()
+        
+        # pulse gauge while working
+        while self.processing and self.processing.isAlive():
+            self.gauge.pulse()
+        
+        # update gui
+        self.updateDocumentsGrid()
+        self.updatePeaklistGrid()
+        self.updateMatchesGrid()
+        
+        # hide processing gauge
+        self.onProcessing(False)
+        self.compare_butt.Enable(True)
+    # ----
+    
+    
     def setData(self, documents):
         """Set data."""
         
         self.currentDocuments = []
-        self.currentPeaklists = []
+        self.currentPeaklist = []
         self.currentMatches = []
         
         # get visible documents only
@@ -324,12 +545,8 @@ class panelComparePeaklists(wx.MiniFrame):
             if document.visible:
                 self.currentDocuments.append(document)
         
-        # get peaklists
-        self.getPeaklists()
-        
-        # update gui
-        self.updateDocumentsGrid()
-        self.updateMatchesGrid()
+        # update peak lists
+        self.onUpdatePeaklist()
     # ----
     
     
@@ -341,15 +558,24 @@ class panelComparePeaklists(wx.MiniFrame):
             
             config.comparePeaklists['tolerance'] = float(self.tolerance_value.GetValue())
             
+            config.comparePeaklists['units'] = 'ppm'
             if self.unitsDa_radio.GetValue():
                 config.comparePeaklists['units'] = 'Da'
-            else:
-                config.comparePeaklists['units'] = 'ppm'
             
+            config.comparePeaklists['ignoreCharge'] = 0
             if self.ignoreCharge_check.GetValue():
                 config.comparePeaklists['ignoreCharge'] = 1
-            else:
-                config.comparePeaklists['ignoreCharge'] = 0
+            
+            config.comparePeaklists['ratioCheck'] = 0
+            if self.ratioCheck_check.GetValue():
+                config.comparePeaklists['ratioCheck'] = 1
+                
+            config.comparePeaklists['ratioDirection'] = -1
+            if self.ratioDirection_choice.GetStringSelection() == 'Above':
+                config.comparePeaklists['ratioDirection'] = 1
+            
+            if self.ratioCheck_check.GetValue():
+                config.comparePeaklists['ratioThreshold'] = float(self.ratioThreshold_value.GetValue())
             
             return True
             
@@ -359,101 +585,126 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
-    def getPeaklists(self):
-        """Filter peaklists according to specified type."""
-        
-        # empty current data
-        self.currentPeaklists = []
-        self.currentMatches = []
-        
-        # get peaklist
-        count = len(self.currentDocuments)
-        for x, document in enumerate(self.currentDocuments):
-            self.currentPeaklists.append([])
-            
-            # use measured notations
-            if config.comparePeaklists['compare'] == 'measured':
-                items = []
-                for item in document.annotations:
-                    items.append(item)
-                for sequence in document.sequences:
-                    for item in sequence.matches:
-                        items.append(item)
-                for item in items:
-                    self.currentPeaklists[-1].append([round(item.mz,6), item.charge, item.ai-item.base, count*[False]])
-                    self.currentPeaklists[-1][-1][-1][x] = True
-            
-            # use theoretical notations
-            elif config.comparePeaklists['compare'] == 'theoretical':
-                items = []
-                for item in document.annotations:
-                    if item.theoretical != None:
-                        items.append(item)
-                for sequence in document.sequences:
-                    for item in sequence.matches:
-                        if item.theoretical != None:
-                            items.append(item)
-                for item in items:
-                    self.currentPeaklists[-1].append([round(item.theoretical,6), item.charge, item.ai-item.base, count*[False]])
-                    self.currentPeaklists[-1][-1][-1][x] = True
-            
-            # use peaklists
-            else:
-                for item in document.spectrum.peaklist:
-                    self.currentPeaklists[-1].append([round(item.mz,6), item.charge, item.ai-item.base, count*[False]])
-                    self.currentPeaklists[-1][-1][-1][x] = True
-    # ----
-    
-    
-    def updateDocumentsGrid(self):
+    def updateDocumentsGrid(self, recreate=True):
         """Update current documents grid."""
         
-        # erase grid
-        if self.documentsGrid.GetNumberCols():
-            self.documentsGrid.DeleteCols(0, self.documentsGrid.GetNumberCols())
-        if self.documentsGrid.GetNumberRows():
-            self.documentsGrid.DeleteRows(0, self.documentsGrid.GetNumberRows())
-        
-        # check peaklist
-        if not self.currentPeaklists:
-            return
-        
-        # make grid
-        count = len(self.currentDocuments)
-        self.documentsGrid.AppendCols(count**2+count)
-        self.documentsGrid.AppendRows(max(len(d) for d in self.currentPeaklists))
+        # make new grid
+        if recreate or not self.currentPeaklist:
+            
+            # erase grid
+            if self.documentsGrid.GetNumberCols():
+                self.documentsGrid.DeleteCols(0, self.documentsGrid.GetNumberCols())
+            if self.documentsGrid.GetNumberRows():
+                self.documentsGrid.DeleteRows(0, self.documentsGrid.GetNumberRows())
+            
+            # check peaklist
+            if not self.currentPeaklist:
+                return
+            
+            # make new grid
+            count = len(self.currentDocuments)
+            self.documentsGrid.AppendCols(count**2+count)
+            self.documentsGrid.AppendRows(self._maxSize)
+            
+            cellAttr = wx.grid.GridCellAttr()
+            cellAttr.SetReadOnly(True)
+            for x in range(count**2+count):
+                self.documentsGrid.SetColAttr(x, cellAttr)
+                if x % (count+1):
+                    self.documentsGrid.SetColLabelValue(x, '*')
+                    self.documentsGrid.SetColSize(x, 20)
+                else:
+                    self.documentsGrid.SetColLabelValue(x, 'm/z')
         
         # set formats
         mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
-        cellAttr = wx.grid.GridCellAttr()
-        cellAttr.SetReadOnly(True)
+        defaultColour = self.documentsGrid.GetDefaultCellBackgroundColour()
         
-        # make grid
-        for i in range(count):
-            col = i*(count+1)
+        # add data
+        rows = [0]*len(self.currentDocuments)
+        count = len(self.currentDocuments)
+        for i, item in enumerate(self.currentPeaklist):
             
-            # make labels
-            self.documentsGrid.SetColLabelValue(col, 'm/z')
-            self.documentsGrid.SetColAttr(col, cellAttr)
+            # get item column and row
+            col = item[1]*(count+1)
+            row = rows[item[1]]
+            rows[item[1]] += 1
+            
+            # add mz
+            mz = mzFormat % item[0]
+            self.documentsGrid.SetCellValue(row, col, mz)
+            
+            # add matches
             for x in range(count):
-                self.documentsGrid.SetColLabelValue(col+1+x, '*')
-                self.documentsGrid.SetColAttr(col+1+x, cellAttr)
-                self.documentsGrid.SetColSize(col+1+x, 20)
-            
-            # add data
-            for j, item in enumerate(self.currentPeaklists[i]):
-                mz = mzFormat % item[0]
-                self.documentsGrid.SetCellValue(j, col, mz)
-                self.documentsGrid.SetCellValue(j, col+i+1, '*')
-                self.documentsGrid.SetCellAlignment(j, col+i+1, wx.ALIGN_CENTER, wx.ALIGN_CENTER)
-                for x in range(count):
-                    if item[-1][x]:
-                        self.documentsGrid.SetCellBackgroundColour(j, col+x+1, self.currentDocuments[x].colour)
+                if item[-1][x]:
+                    self.documentsGrid.SetCellBackgroundColour(row, col+x+1, self.currentDocuments[x].colour)
+                else:
+                    self.documentsGrid.SetCellBackgroundColour(row, col+x+1, defaultColour)
+                
+                if x == item[1]:
+                    self.documentsGrid.SetCellValue(row, col+x+1, '*')
+                    self.documentsGrid.SetCellAlignment(row, col+x+1, wx.ALIGN_CENTER, wx.ALIGN_CENTER)
         
         self.documentsGrid.AutoSizeColumns(True)
     # ----
     
     
+    def updatePeaklistGrid(self, recreate=True):
+        """Update current total peaklist grid."""
+        
+        # make new grid
+        if recreate or not self.currentPeaklist:
+            
+            # erase grid
+            if self.peaklistGrid.GetNumberCols():
+                self.peaklistGrid.DeleteCols(0, self.peaklistGrid.GetNumberCols())
+            if self.peaklistGrid.GetNumberRows():
+                self.peaklistGrid.DeleteRows(0, self.peaklistGrid.GetNumberRows())
+            
+            # check peaklist
+            if not self.currentPeaklist:
+                return
+            
+            # make new grid
+            count = len(self.currentDocuments)
+            self.peaklistGrid.AppendCols(count+1)
+            self.peaklistGrid.AppendRows(len(self.currentPeaklist))
+            self.peaklistGrid.SetColLabelValue(0, 'm/z')
+            cellAttr = wx.grid.GridCellAttr()
+            cellAttr.SetReadOnly(True)
+            for x in range(count+1):
+                self.peaklistGrid.SetColAttr(x, cellAttr)
+            for x in range(1, count+1):
+                self.peaklistGrid.SetColLabelValue(x, '*')
+                self.peaklistGrid.SetColSize(x, 20)
+        
+        # set formats
+        mzFormat = '%0.' + `config.main['mzDigits']` + 'f'
+        defaultColour = self.peaklistGrid.GetDefaultCellBackgroundColour()
+        
+        # add data
+        count = len(self.currentDocuments)
+        for i, item in enumerate(self.currentPeaklist):
+            
+            # add mz
+            mz = mzFormat % item[0]
+            self.peaklistGrid.SetCellValue(i, 0, mz)
+            
+            # add matches
+            for x in range(count):
+                if item[-1][x]:
+                    self.peaklistGrid.SetCellBackgroundColour(i, x+1, self.currentDocuments[x].colour)
+                else:
+                    self.peaklistGrid.SetCellBackgroundColour(i, x+1, defaultColour)
+                
+                if x == item[1]:
+                    self.peaklistGrid.SetCellValue(i, x+1, '*')
+                    self.peaklistGrid.SetCellAlignment(i, x+1, wx.ALIGN_CENTER, wx.ALIGN_CENTER)
+        
+        self.peaklistGrid.AutoSizeColumns(True)
+    # ----
+    
+    
     def updateMatchesGrid(self):
         """Update current matches."""
         
@@ -507,72 +758,149 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
-    def compareAll(self):
+    def runGetPeaklists(self):
+        """Filter peaklists according to specified type."""
+        
+        # empty current data
+        self.currentPeaklist = []
+        self.currentMatches = []
+        self._maxSize = 0
+        
+        # run task
+        try:
+            
+            # get peaklist
+            count = len(self.currentDocuments)
+            for x, document in enumerate(self.currentDocuments):
+                size = 0
+                
+                # use measured notations
+                if config.comparePeaklists['compare'] == 'measured':
+                    items = []
+                    for item in document.annotations:
+                        items.append(item)
+                    for sequence in document.sequences:
+                        for item in sequence.matches:
+                            items.append(item)
+                    for item in items:
+                        # [mz, docIndex, z, intensity, [matches]]
+                        self.currentPeaklist.append( [ round(item.mz,6), x, item.charge, item.ai-item.base, count*[False] ] )
+                        self.currentPeaklist[-1][-1][x] = True
+                        size += 1
+                
+                # use theoretical notations
+                elif config.comparePeaklists['compare'] == 'theoretical':
+                    items = []
+                    for item in document.annotations:
+                        if item.theoretical != None:
+                            items.append(item)
+                    for sequence in document.sequences:
+                        for item in sequence.matches:
+                            if item.theoretical != None:
+                                items.append(item)
+                    for item in items:
+                        self.currentPeaklist.append( [ round(item.theoretical,6), x, item.charge, item.ai-item.base, count*[False] ] )
+                        self.currentPeaklist[-1][-1][x] = True
+                        size += 1
+                
+                # use peaklists
+                else:
+                    for item in document.spectrum.peaklist:
+                        self.currentPeaklist.append( [ round(item.mz,6), x, item.charge, item.ai-item.base, count*[False] ] )
+                        self.currentPeaklist[-1][-1][x] = True
+                        size += 1
+                
+                # remember max peaklist size
+                self._maxSize = max(size, self._maxSize)
+            
+            # sort peaklist by mz
+            self.currentPeaklist.sort()
+        
+        # task canceled
+        except mspy.ForceQuit:
+            self.currentPeaklist = []
+            self._maxSize = 0
+            return
+    # ----
+    
+    
+    def runCompare(self):
         """Compare all peaklists."""
         
         self.currentMatches = []
         
-        # get total peaklist and erase previous matches
-        peaklist = []
-        count = len(self.currentPeaklists)
-        for i, pkl in enumerate(self.currentPeaklists):
-            for j, pk in enumerate(pkl):
-                peaklist.append([pk[0], pk[1], i, j])
-                self.currentPeaklists[i][j][-1] = count*[False]
-                self.currentPeaklists[i][j][-1][i] = True
-        peaklist.sort()
+        # run task
+        try:
+            
+            # erase previous matches
+            count = len(self.currentDocuments)
+            for i, item in enumerate(self.currentPeaklist):
+                item[-1] = count*[False]
+                item[-1][item[1]] = True
+            
+            # compare peaklists
+            count = len(self.currentPeaklist)
+            for i in range(count):
+                for j in range(i, count):
+                    p1 = self.currentPeaklist[i]
+                    p2 = self.currentPeaklist[j]
+                    matched = False
+                    
+                    # check charge
+                    if not config.comparePeaklists['ignoreCharge'] and (p1[2] != p2[2]) and (p1[2] != None and p2[2] != None):
+                        continue
+                    
+                    # check error
+                    error = mspy.delta(p1[0], p2[0], config.comparePeaklists['units'])
+                    if abs(error) <= config.comparePeaklists['tolerance']:
+                        matched = True
+                    elif error < 0:
+                        break
+                    
+                    # check ratio
+                    if matched and config.comparePeaklists['ratioCheck'] and p1[3] and p2[3]:
+                        
+                        ratio = p1[3]/p2[3]
+                        if config.comparePeaklists['ratioThreshold'] > 1 and ratio < 1 \
+                        or config.comparePeaklists['ratioThreshold'] < 1 and ratio > 1:
+                            ratio = 1./ratio
+                        
+                        if (config.comparePeaklists['ratioDirection'] == 1 and ratio < config.comparePeaklists['ratioThreshold']) \
+                        or (config.comparePeaklists['ratioDirection'] == -1 and ratio > config.comparePeaklists['ratioThreshold']):
+                            matched = False
+                    
+                    # save matched
+                    if matched:
+                        p1[-1][p2[1]] = True
+                        p2[-1][p1[1]] = True
         
-        # compare peaklists
-        count = len(peaklist)
-        for i in range(count):
-            for j in range(i, count):
-                p1 = peaklist[i]
-                p2 = peaklist[j]
-                
-                # check charge
-                if not config.comparePeaklists['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
-                    continue
-                
-                # check error
-                error = mspy.delta(p1[0], p2[0], config.comparePeaklists['units'])
-                if abs(error) <= config.comparePeaklists['tolerance']:
-                    self.currentPeaklists[p1[2]][p1[3]][-1][p2[2]] = True
-                    self.currentPeaklists[p2[2]][p2[3]][-1][p1[2]] = True
-                elif error < 0:
-                    break
+        # task canceled
+        except mspy.ForceQuit:
+            return
     # ----
     
     
-    def compareSelected(self, docIndex, pkIndex):
+    def compareSelected(self, pkIndex):
         """Compare selected mass only."""
         
         self.currentMatches = []
         
         # get current peak
-        peak = self.currentPeaklists[docIndex][pkIndex]
-        p1 = [peak[0], peak[1], peak[2], docIndex, pkIndex]
-        
-        # get total peaklist
-        peaklist = []
-        for i, pkl in enumerate(self.currentPeaklists):
-            if i != docIndex:
-                for j, pk in enumerate(pkl):
-                    peaklist.append([pk[0], pk[1], pk[2], i, j])
-        peaklist.sort()
+        p1 = self.currentPeaklist[pkIndex]
         
         # compare mass
-        for p2 in peaklist:
+        for p2 in self.currentPeaklist:
             
             # check charge
-            if not config.comparePeaklists['ignoreCharge'] and (p1[1] != p2[1]) and (p1[1] != None and p2[1] != None):
+            if not config.comparePeaklists['ignoreCharge'] and (p1[2] != p2[2]) and (p1[2] != None and p2[2] != None):
                 continue
             
             # check error
             error = mspy.delta(p1[0], p2[0], config.comparePeaklists['units'])
             if abs(error) <= config.comparePeaklists['tolerance']:
-                ratio1 = p1[2]/p2[2]
+                ratio1 = p1[3]/p2[3]
                 ratio2 = 1/ratio1
-                self.currentMatches.append([p2[3], p2[0], error, ratio1, ratio2, p2[3]==docIndex])
+                self.currentMatches.append([p2[1], p2[0], error, ratio1, ratio2, p1[1]==p2[1]])
             elif error < 0:
                 break
         
@@ -609,6 +937,34 @@ class panelComparePeaklists(wx.MiniFrame):
     # ----
     
     
+    def copyPeaklist(self):
+        """Copy total peaklist table into clipboard."""
+        
+        # get default bgr colour
+        defaultColour = self.peaklistGrid.GetDefaultCellBackgroundColour()
+        
+        # get data
+        buff = ''
+        for row in range(self.peaklistGrid.GetNumberRows()):
+            line = ''
+            for col in range(self.peaklistGrid.GetNumberCols()):
+                value = self.peaklistGrid.GetCellValue(row, col)
+                if value == '' and defaultColour != self.peaklistGrid.GetCellBackgroundColour(row, col):
+                    value = "x"
+                line += value + '\t'
+            buff += '%s\n' % (line.rstrip())
+        
+        # make text object for data
+        obj = wx.TextDataObject()
+        obj.SetText(buff.rstrip())
+        
+        # paste to clipboard
+        if wx.TheClipboard.Open():
+            wx.TheClipboard.SetData(obj)
+            wx.TheClipboard.Close()
+    # ----
+    
+    
     def copyMatches(self):
         """Copy matches table into clipboard."""
         
