@@ -100,10 +100,10 @@ class panelEnvelopeFit(wx.MiniFrame):
         
         exchange_label = wx.StaticText(panel, -1, "Exchange:")
         exchange_label.SetFont(wx.SMALL_FONT)
-        self.exchangeLoss_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['loss']), size=(40,  -1))
+        self.exchangeLoss_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['loss']), size=(60,  -1))
         exchangeVs_label = wx.StaticText(panel, -1, " vs.")
         exchangeVs_label.SetFont(wx.SMALL_FONT)
-        self.exchangeGain_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['gain']), size=(40,  -1))
+        self.exchangeGain_value = mwx.formulaCtrl(panel, -1, str(config.envelopeFit['gain']), size=(60,  -1))
         
         scale_label = wx.StaticText(panel, -1, "Range:")
         scale_label.SetFont(wx.SMALL_FONT)
@@ -140,8 +140,8 @@ class panelEnvelopeFit(wx.MiniFrame):
         
         mainSizer = wx.BoxSizer(wx.VERTICAL)
         mainSizer.Add(sizer, 1, wx.EXPAND)
-        panel.SetSizer(mainSizer)
         mainSizer.Fit(panel)
+        panel.SetSizer(mainSizer)
         
         return panel
     # ----
@@ -179,7 +179,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.forceFwhm_check.SetFont(wx.SMALL_FONT)
         self.forceFwhm_check.SetValue(config.envelopeFit['forceFwhm'])
         
-        relThreshold_label = wx.StaticText(panel, -1, "Rel. threshold:")
+        relThreshold_label = wx.StaticText(panel, -1, "Rel. int. threshold:")
         relThreshold_label.SetFont(wx.SMALL_FONT)
         relThresholdUnits_label = wx.StaticText(panel, -1, "%")
         relThresholdUnits_label.SetFont(wx.SMALL_FONT)
@@ -260,6 +260,7 @@ class panelEnvelopeFit(wx.MiniFrame):
         self.spectrumCanvas.setProperties(showPosBar=False)
         self.spectrumCanvas.setProperties(showIntBar=True)
         self.spectrumCanvas.setProperties(showGel=False)
+        self.spectrumCanvas.setProperties(zoomAxis='x')
         self.spectrumCanvas.setProperties(checkLimits=True)
         self.spectrumCanvas.setProperties(autoScaleY=True)
         self.spectrumCanvas.setProperties(reverseScrolling=config.main['reverseScrolling'])
