@@ -246,6 +246,7 @@ class panelMatch(wx.MiniFrame):
         self.errorCanvas.setProperties(showPosBar=True)
         self.errorCanvas.setProperties(posBarHeight=6)
         self.errorCanvas.setProperties(showGel=False)
+        self.errorCanvas.setProperties(zoomAxis='x')
         self.errorCanvas.setProperties(checkLimits=True)
         self.errorCanvas.setProperties(autoScaleY=False)
         self.errorCanvas.setProperties(xPosDigits=config.main['mzDigits'])
@@ -646,7 +647,7 @@ class panelMatch(wx.MiniFrame):
                     mspy.CHECK_FORCE_QUIT()
                     
                     # check charge
-                    if (chargeCol==None or peak.charge==None or config.match['ignoreCharge'] or (peak.charge and item[chargeCol]==abs(peak.charge))):
+                    if (chargeCol==None or peak.charge==None or config.match['ignoreCharge'] or peak.charge==item[chargeCol]):
                         
                         # check mass tolerance
                         error = mspy.delta(peak.mz, item[massCol], config.match['units'])
