@@ -107,6 +107,7 @@ class panelSpectrum(wx.Panel):
         self.spectrumCanvas.setProperties(showCurImage=config.spectrum['showCursorImage'])
         self.spectrumCanvas.setProperties(autoScaleY=config.spectrum['autoscale'])
         self.spectrumCanvas.setProperties(overlapLabels=config.spectrum['overlapLabels'])
+        self.spectrumCanvas.setProperties(zoomAxis='x')
         self.spectrumCanvas.setProperties(checkLimits=config.spectrum['checkLimits'])
         self.spectrumCanvas.setProperties(xPosDigits=config.main['mzDigits'])
         self.spectrumCanvas.setProperties(yPosDigits=config.main['intDigits'])
@@ -468,6 +469,7 @@ class panelSpectrum(wx.Panel):
         spectrum.setProperties(showPoints=config.spectrum['showDataPoints'])
         spectrum.setProperties(showGelLegend=config.spectrum['showGelLegend'])
         spectrum.setProperties(spectrumColour=docData.colour)
+        spectrum.setProperties(spectrumStyle=docData.style)
         
         spectrum.setProperties(labelAngle=config.spectrum['labelAngle'])
         spectrum.setProperties(labelCharge=config.spectrum['labelCharge'])
