@@ -54,8 +54,8 @@ class mMass(wx.App):
         except: pass
         
         # open file from commandline
-        if len(sys.argv) == 2:
-            self.frame.onDocumentOpen(path=sys.argv[1])
+        if len(sys.argv) >= 2:
+            self.frame.onDocumentDropped(paths=sys.argv[1:])
         
         return True
     # ----
@@ -128,7 +128,7 @@ class TCPServerHandler(SocketServer.BaseRequestHandler):
         self.server.app.onServerCommand(command)
     # ----
     
-
+    
 
 
 if __name__ == '__main__':
