@@ -42,6 +42,7 @@ class compound:
         self._composition = None
         self._formula = None
         self._mass = None
+        self._nominalmass = None
         
         # get additional attributes
         self.attributes = {}
@@ -73,6 +74,7 @@ class compound:
         self._composition = None
         self._formula = None
         self._mass = None
+        self._nominalmass = None
     # ----
     
     
@@ -217,6 +219,47 @@ class compound:
     # ----
     
     
+    def nominalmass(self, massType=None):
+        """Get nominal mass."""
+        
+        # get mass
+        if self._nominalmass == None:
+            massMo = 0
+            massAv = 0
+            
+            # get composition
+            comp = self.composition()
+            
+            # get mass for each atom
+            for atom in comp:
+                count = comp[atom]
+                
+                # check specified isotope and mass
+                match = mod_basics.ELEMENT_PATTERN.match(atom)
+                symbol, massNumber, tmp = match.groups()
+                if massNumber:
+                    isotope = blocks.elements[symbol].isotopes[int(massNumber)]
+                    atomMass = (isotope[0], isotope[0])
+                else:
+                    atomMass = blocks.elements[symbol].mass
+                
+                # multiply atom mass
+                massMo += round(atomMass[0])*count
+                massAv += round(atomMass[1])*count
+            
+            # store mass in buffer
+            self._nominalmass = (massMo, massAv)
+        
+        # return nominal mass
+        if massType == 0:
+            return self._nominalmass[0]
+        elif massType ==  1:
+            return self._nominalmass[1]
+        else:
+            return self._nominalmass
+    # ----
+    
+    
     def mz(self, charge, agentFormula='H', agentCharge=1):
         """Get ion m/z."""
         
