@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,11 +12,12 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
 import xml.sax
+import xml.dom.minidom
 import base64
 import struct
 import os.path
@@ -24,10 +25,12 @@ import numpy
 from copy import deepcopy
 
 # load stopper
-from stopper import CHECK_FORCE_QUIT
+from mod_stopper import CHECK_FORCE_QUIT
 
-# register essential objects
-import objects
+# load objects
+import obj_peak
+import obj_peaklist
+import obj_scan
 
 
 # PARSE mzData DATA
@@ -78,7 +81,7 @@ class parseMZDATA():
     # ----
     
     
-    def getInfo(self):
+    def info(self):
         """Get document info."""
         
         # get preloaded data if available
@@ -104,7 +107,7 @@ class parseMZDATA():
     # ----
     
     
-    def getScanlist(self):
+    def scanlist(self):
         """Get list of all scans in the document."""
         
         # use preloaded data if available
@@ -129,13 +132,19 @@ class parseMZDATA():
     # ----
     
     
-    def getScan(self, scanID=None):
+    def scan(self, scanID=None):
         """Get spectrum from document."""
         
         # use preloaded data if available
         if self._scans and scanID in self._scans:
             data = self._scans[scanID]
         
+        # faster loading of single-scan documents
+        elif scanID == None:
+            parser = singleScanParser(self.path)
+            parser.parse()
+            data = parser.data
+        
         # parse file
         else:
             handler = scanHandler(scanID)
@@ -167,10 +176,10 @@ class parseMZDATA():
         points = self._parsePoints(scanData)
         if scanData['spectrumType'] == 'discrete':
             for x, p in enumerate(points):
-                points[x] = objects.peak(p[0], p[1])
-            scan = objects.scan(peaks=objects.peaklist(points))
+                points[x] = obj_peak.peak(p[0], p[1])
+            scan = obj_scan.scan(peaklist=obj_peaklist.peaklist(points))
         else:
-            scan = objects.scan(points=points)
+            scan = obj_scan.scan(profile=points)
         
         # set metadata
         scan.title = scanData['title']
@@ -818,6 +827,183 @@ class runHandler(xml.sax.handler.ContentHandler):
     
     
 
+class singleScanParser():
+    """Faster loading of single-scan documents."""
+    
+    def __init__(self, path):
+        
+        self.path = path
+        self.data = None
+        self._parsedData = None
+    # ----
+    
+    
+    def parse(self):
+        """Parse document."""
+        
+        # read xml
+        try:
+            doc = file(self.path)
+            rawData = doc.read()
+            doc.close()
+            self._parsedData = xml.dom.minidom.parseString(rawData)
+        except:
+            self.data = None
+            return
+        
+        # init data
+        self.data = {
+                'title': '',
+                'scanNumber': None,
+                'parentScanNumber': None,
+                'msLevel': None,
+                'pointsCount': None,
+                'polarity': None,
+                'retentionTime': None,
+                'lowMZ': None,
+                'highMZ': None,
+                'basePeakMZ': None,
+                'basePeakIntensity': None,
+                'totIonCurrent': None,
+                'precursorMZ': None,
+                'precursorIntensity': None,
+                'precursorCharge': None,
+                'spectrumType': 'unknown',
+                
+                'mzData': None,
+                'mzEndian': None,
+                'mzPrecision': None,
+                'intData': None,
+                'intEndian': None,
+                'intPrecision': None,
+        }
+        
+        # parse xml
+        self.handleSpectrum()
+        self.handleMetadata()
+    # ----
+    
+    
+    def handleSpectrum(self):
+        """Get spectrum data."""
+        
+        # get spectrum type
+        acqSpecificationTags = self._parsedData.getElementsByTagName('acqSpecification')
+        if acqSpecificationTags:
+            self.data['spectrumType'] = acqSpecificationTags[0].getAttribute('spectrumType')
+        
+        # get mz data
+        mzArrayBinaryTags = self._parsedData.getElementsByTagName('mzArrayBinary')
+        if mzArrayBinaryTags:
+            dataTags = mzArrayBinaryTags[0].getElementsByTagName('data')
+            if dataTags:
+                
+                # get points count
+                attribute = dataTags[0].getAttribute('length')
+                if attribute:
+                    self.data['pointsCount'] = int(attribute)
+                
+                # get endian
+                attribute = dataTags[0].getAttribute('endian')
+                if attribute:
+                    self.data['mzEndian'] = attribute
+                
+                # get precision
+                attribute = dataTags[0].getAttribute('precision')
+                if attribute:
+                    try: self.data['mzPrecision'] = int(attribute)
+                    except ValueError: pass
+                
+                # get array data
+                self.data['mzData'] = ''
+                for node in dataTags[0].childNodes:
+                    if node.nodeType == node.TEXT_NODE:
+                        self.data['mzData'] += node.data
+        
+        # get int data
+        intenArrayBinaryTags = self._parsedData.getElementsByTagName('intenArrayBinary')
+        if intenArrayBinaryTags:
+            dataTags = intenArrayBinaryTags[0].getElementsByTagName('data')
+            if dataTags:
+                
+                # get endian
+                attribute = dataTags[0].getAttribute('endian')
+                if attribute:
+                    self.data['intEndian'] = attribute
+                
+                # get precision
+                attribute = dataTags[0].getAttribute('precision')
+                if attribute:
+                    try: self.data['intPrecision'] = int(attribute)
+                    except ValueError: pass
+                
+                # get array data
+                self.data['intData'] = ''
+                for node in dataTags[0].childNodes:
+                    if node.nodeType == node.TEXT_NODE:
+                        self.data['intData'] += node.data
+    # ----
+    
+    
+    def handleMetadata(self):
+        """Get metadata."""
+        
+        # get spectrum params
+        spectrumInstrumentTags = self._parsedData.getElementsByTagName('spectrumInstrument')
+        if spectrumInstrumentTags:
+            
+            # get ms level
+            attribute = spectrumInstrumentTags[0].getAttribute('msLevel')
+            if attribute:
+                self.data['msLevel'] = int(attribute)
+            
+            # get low m/z
+            attribute = spectrumInstrumentTags[0].getAttribute('mzRangeStart')
+            if attribute:
+                self.data['lowMZ'] = float(attribute)
+            
+            # get high m/z
+            attribute = spectrumInstrumentTags[0].getAttribute('mzRangeStop')
+            if attribute:
+                self.data['highMZ'] = float(attribute)
+        
+        # get cvParams
+        cvParamTags = self._parsedData.getElementsByTagName('cvParam')
+        for cvParamTag in cvParamTags:
+            
+            paramName = cvParamTag.getAttribute('name')
+            paramValue = cvParamTag.getAttribute('value')
+            
+            # get retention time
+            if paramName == 'TimeInMinutes' and paramValue:
+                try: self.data['retentionTime'] = float(paramValue)*60
+                except ValueError: pass
+            
+            # get total ion current
+            elif paramName == 'TotalIonCurrent' and paramValue:
+                try: self.data['totIonCurrent'] = float(paramValue)
+                except ValueError: pass
+            
+            # get precursor m/z
+            elif paramName == 'MassToChargeRatio' and paramValue:
+                try: self.data['precursorMZ'] = float(paramValue)
+                except ValueError: pass
+            
+            # get precursor charge
+            elif paramName == 'ChargeState' and paramValue:
+                try: self.data['precursorCharge'] = int(paramValue)
+                except ValueError: pass
+            
+            # get polarity
+            elif paramName == 'Polarity':
+                if paramValue in ('positive', 'Positive', '+'):
+                    self.data['polarity'] = 1
+                elif paramValue == ('negative', 'Negative', '-'):
+                    self.data['polarity'] = -1
+    # ----
+    
+    
+
 class stopParsing(Exception):
     """Exeption to stop parsing XML data."""
     pass
