@@ -1,5 +1,5 @@
 # -------------------------------------------------------------------------
-#     Copyright (C) 2005-2011 Martin Strohalm <www.mmass.org>
+#     Copyright (C) 2005-2012 Martin Strohalm <www.mmass.org>
 
 #     This program is free software; you can redistribute it and/or modify
 #     it under the terms of the GNU General Public License as published by
@@ -12,7 +12,7 @@
 #     GNU General Public License for more details.
 
 #     Complete text of GNU GPL can be found in the file LICENSE.TXT in the
-#     main directory of the program
+#     main directory of the program.
 # -------------------------------------------------------------------------
 
 # load libs
@@ -20,10 +20,12 @@ import re
 import os.path
 
 # load stopper
-from stopper import CHECK_FORCE_QUIT
+from mod_stopper import CHECK_FORCE_QUIT
 
-# register essential objects
-import objects
+# load objects
+import obj_peak
+import obj_peaklist
+import obj_scan
 
 
 # PARSE SIMPLE ASCII XY
@@ -41,7 +43,7 @@ class parseXY():
     # ----
     
     
-    def getInfo(self):
+    def info(self):
         """Get document info."""
         
         data = {
@@ -58,7 +60,7 @@ class parseXY():
     # ----
     
     
-    def getScan(self, dataType='continuous'):
+    def scan(self, dataType='continuous'):
         """Get spectrum from document."""
         
         # parse file
@@ -118,12 +120,12 @@ class parseXY():
         if dataType == 'discrete':
             buff = []
             for point in scanData:
-                buff.append(objects.peak(point[0], point[1]))
-            scan = objects.scan(peaks=objects.peaklist(buff))
+                buff.append(obj_peak.peak(point[0], point[1]))
+            scan = obj_scan.scan(peaklist=obj_peaklist.peaklist(buff))
         
         # parse data as spectrum (continuous line)
         else:
-            scan = objects.scan(points=scanData)
+            scan = obj_scan.scan(profile=scanData)
         
         return scan
     # ----
