@@ -69,6 +69,7 @@ class canvas(wx.Panel):
             'xScaleFactor': 0.1,
             'yScaleFactor': 0.1,
             'maxZoom': 0.001,
+            'zoomAxis': 'xy',
             'checkLimits': True,
             'reverseScrolling': False,
             'reverseDrawing': False,
@@ -407,10 +408,16 @@ class canvas(wx.Panel):
             # get X axis
             minX = min(self.draggingStart[0], self.cursorPosition[0])
             maxX = max(self.draggingStart[0], self.cursorPosition[0])
+            minY = min(self.draggingStart[1], self.cursorPosition[1])
+            maxY = max(self.draggingStart[1], self.cursorPosition[1])
             
             # zoom plot
-            if minX != maxX:
-                self.zoom((minX, maxX))
+            if self.properties['zoomAxis'] == 'xy' and minX != maxX and minY != maxY:
+                self.zoom(xAxis=(minX, maxX), yAxis=(minY, maxY))
+            elif self.properties['zoomAxis'] == 'x' and minX != maxX:
+                self.zoom(xAxis=(minX, maxX))
+            elif self.properties['zoomAxis'] == 'y' and minY != maxY:
+                self.zoom(yAxis=(minY, maxY))
             
         # axis scaling
         elif self.mouseEvent in ('xScale', 'yScale'):
@@ -1798,7 +1805,7 @@ class canvas(wx.Panel):
     # ----
     
     
-    def drawZoomBox(self):
+    def drawZoomBox_(self):
         """Draw zoom-box"""
         
         # get coordinations
@@ -1839,6 +1846,66 @@ class canvas(wx.Panel):
     # ----
     
     
+    def drawZoomBox(self):
+        """Draw zoom-box"""
+        
+        # get coordinations
+        minX = self.draggingStart[2]
+        minY = self.draggingStart[3]
+        maxX = self.cursorPosition[2]
+        maxY = self.cursorPosition[3]
+        
+        minXPlot = self.plotCoords[0]
+        minYPlot = self.plotCoords[1]
+        maxXPlot = self.plotCoords[2]
+        maxYPlot = self.plotCoords[3]
+        
+        # check limits
+        minX = min(minX, maxXPlot)
+        minX = max(minX, minXPlot)
+        minY = min(minY, maxYPlot)
+        minY = max(minY, minYPlot)
+        maxX = min(maxX, maxXPlot)
+        maxX = max(maxX, minXPlot)
+        maxY = min(maxY, maxYPlot)
+        maxY = max(maxY, minYPlot)
+        
+        # get gel coords
+        if self.properties['showGel']:
+            minYGel = minYPlot - (8 * self.printerScale['drawings'])
+            maxYGel = minYGel - self.gelsCount * self.properties['gelHeight']
+        
+        # set canvas and pen
+        dc = wx.ClientDC(self.canvas)
+        dc.BeginDrawing()
+        dc.SetPen(wx.Pen(wx.BLACK))
+        dc.SetBrush(wx.Brush(wx.WHITE, wx.SOLID))
+        dc.SetLogicalFunction(wx.INVERT)
+        
+        # draw clasic zoom box
+        if self.properties['zoomAxis'] == 'xy':
+            dc.DrawRectangle(minX, minY, maxX - minX, maxY-minY)
+        
+        # draw X-axis-zoom-only box
+        elif self.properties['zoomAxis'] == 'x':
+            dc.DrawRectangle(minX, maxYPlot, maxX - minX, minYPlot - maxYPlot)
+        
+        # draw Y-axis-only zoom box
+        elif self.properties['zoomAxis'] == 'y':
+            dc.DrawRectangle(minXPlot, maxY, maxXPlot - minXPlot, minY - maxY)
+        
+        # draw gellview zoombox
+        if self.properties['showGel'] and self.properties['zoomAxis'] == 'x':
+            minYGel += self.printerScale['drawings']
+            maxYGel -= self.printerScale['drawings']
+            dc.DrawRectangle(minX, maxYGel, maxX - minX, minYGel-maxYGel)
+        
+        # resset canvas and pen
+        dc.SetLogicalFunction(wx.COPY)
+        dc.EndDrawing()
+    # ----
+    
+    
     def drawSelectionRect(self):
         """Draw selection rectangle"""
         
