@@ -601,6 +601,7 @@ class points:
                             'showPoints': True,
                             'pointColour': (0, 0, 255),
                             'pointSize': 3,
+                            'fillPoints': True,
                             'showLines': True,
                             'lineColour': (0, 0, 255),
                             'lineWidth': 1,
@@ -791,17 +792,26 @@ class points:
         
         # draw lines
         if self.properties['showLines'] and len(self.scaled) > 1:
+            
             pen = wx.Pen(self.properties['lineColour'], self.properties['lineWidth']*printerScale['drawings'], self.properties['lineStyle'])
             brush = wx.Brush(self.properties['lineColour'], wx.SOLID)
+            
             dc.SetPen(pen)
             dc.SetBrush(brush)
             dc.DrawLines(self.scaled)
         
         # draw points
         if self.properties['showPoints']:
-            pencolour = [max(x-70,0) for x in self.properties['pointColour']]
-            pen = wx.Pen(pencolour, self.properties['lineWidth']*printerScale['drawings'], wx.SOLID)
-            brush = wx.Brush(self.properties['pointColour'], wx.SOLID)
+            
+            if self.properties['fillPoints']:
+                pencolour = [max(x-70,0) for x in self.properties['pointColour']]
+                pen = wx.Pen(pencolour, self.properties['lineWidth']*printerScale['drawings'], wx.SOLID)
+                brush = wx.Brush(self.properties['pointColour'], wx.SOLID)
+            else:
+                pencolour = self.properties['pointColour']
+                pen = wx.Pen(pencolour, self.properties['lineWidth']*printerScale['drawings'], wx.SOLID)
+                brush = wx.TRANSPARENT_BRUSH
+            
             dc.SetPen(pen)
             dc.SetBrush(brush)
             for point in self.scaled:
@@ -1232,6 +1242,10 @@ class spectrum:
         # draw lines
         dc.DrawLines(self.spectrumScaled)
         
+        # set pen for points
+        pen = wx.Pen(self.properties['spectrumColour'], self.properties['spectrumWidth']*printerScale['drawings'], wx.SOLID)
+        dc.SetPen(pen)
+        
         # draw points if it makes sense
         count = len(self.spectrumScaled)
         if self.properties['showPoints'] \
